@@ -38,7 +38,8 @@ extern "C" {
 DCORE_USE_NAMESPACE
 
 QT_BEGIN_NAMESPACE
-extern Q_WIDGETS_EXPORT void qt_blurImage(QPainter *p, QImage &blurImage, qreal radius, bool quality, bool alphaOnly, int transposed = 0);
+extern Q_WIDGETS_EXPORT void
+qt_blurImage(QPainter *p, QImage &blurImage, qreal radius, bool quality, bool alphaOnly, int transposed = 0);
 QT_END_NAMESPACE
 
 QString Utils::m_systemLanguage;
@@ -63,7 +64,7 @@ QSize Utils::getRenderSize(int fontSize, const QString &string)
     int height = 0;
 
     for (const QString &line : string.split("\n")) {
-        int lineWidth = fm.width(line);
+        int lineWidth = fm.horizontalAdvance(line);
         int lineHeight = fm.height();
 
         if (lineWidth > width) {
@@ -110,63 +111,60 @@ float Utils::codecConfidenceForData(const QTextCodec *codec, const QByteArray &d
             ++non_base_latin_count;
 
         switch (ch.script()) {
-        case QChar::Script_Hiragana:
-        case QChar::Script_Katakana:
-            hep_count += (country == QLocale::Japan) ? 1.2 : 0.5;
-            unidentification_count += (country == QLocale::Japan) ? 0 : 0.3;
-            break;
-        case QChar::Script_Han:
-            hep_count += (country == QLocale::China) ? 1.2 : 0.5;
-            unidentification_count += (country == QLocale::China) ? 0 : 0.3;
-            break;
-        case QChar::Script_Hangul:
-            hep_count += (country == QLocale::NorthKorea) || (country == QLocale::SouthKorea) ? 1.2 : 0.5;
-            unidentification_count += (country == QLocale::NorthKorea) || (country == QLocale::SouthKorea) ? 0 : 0.3;
-            break;
-        case QChar::Script_Cyrillic:
-            hep_count += (country == QLocale::Russia) ? 1.2 : 0.5;
-            unidentification_count += (country == QLocale::Russia) ? 0 : 0.3;
-            break;
-        case QChar::Script_Devanagari:
-            hep_count += (country == QLocale::Nepal || country == QLocale::India) ? 1.2 : 0.5;
-            unidentification_count += (country == QLocale::Nepal || country == QLocale::India) ? 0 : 0.3;
-            break;
-        default:
-            // full-width character, emoji, 常用标点, 拉丁文补充1，天城文补充，CJK符号和标点符号（如：【】）
-            if ((ch.unicode() >= 0xff00 && ch <= 0xffef)
-                || (ch.unicode() >= 0x2600 && ch.unicode() <= 0x27ff)
-                || (ch.unicode() >= 0x2000 && ch.unicode() <= 0x206f)
-                || (ch.unicode() >= 0x80 && ch.unicode() <= 0xff)
-                || (ch.unicode() >= 0xa8e0 && ch.unicode() <= 0xa8ff)
-                || (ch.unicode() >= 0x0900 && ch.unicode() <= 0x097f)
-                || (ch.unicode() >= 0x3000 && ch.unicode() <= 0x303f)) {
-                ++hep_count;
-            } else if (ch.isSurrogate() && ch.isHighSurrogate()) {
-                ++i;
+            case QChar::Script_Hiragana:
+            case QChar::Script_Katakana:
+                hep_count += (country == QLocale::Japan) ? 1.2 : 0.5;
+                unidentification_count += (country == QLocale::Japan) ? 0 : 0.3;
+                break;
+            case QChar::Script_Han:
+                hep_count += (country == QLocale::China) ? 1.2 : 0.5;
+                unidentification_count += (country == QLocale::China) ? 0 : 0.3;
+                break;
+            case QChar::Script_Hangul:
+                hep_count += (country == QLocale::NorthKorea) || (country == QLocale::SouthKorea) ? 1.2 : 0.5;
+                unidentification_count += (country == QLocale::NorthKorea) || (country == QLocale::SouthKorea) ? 0 : 0.3;
+                break;
+            case QChar::Script_Cyrillic:
+                hep_count += (country == QLocale::Russia) ? 1.2 : 0.5;
+                unidentification_count += (country == QLocale::Russia) ? 0 : 0.3;
+                break;
+            case QChar::Script_Devanagari:
+                hep_count += (country == QLocale::Nepal || country == QLocale::India) ? 1.2 : 0.5;
+                unidentification_count += (country == QLocale::Nepal || country == QLocale::India) ? 0 : 0.3;
+                break;
+            default:
+                // full-width character, emoji, 常用标点, 拉丁文补充1，天城文补充，CJK符号和标点符号（如：【】）
+                if ((ch.unicode() >= 0xff00 && ch.unicode() <= 0xffef) || (ch.unicode() >= 0x2600 && ch.unicode() <= 0x27ff) ||
+                    (ch.unicode() >= 0x2000 && ch.unicode() <= 0x206f) || (ch.unicode() >= 0x80 && ch.unicode() <= 0xff) ||
+                    (ch.unicode() >= 0xa8e0 && ch.unicode() <= 0xa8ff) || (ch.unicode() >= 0x0900 && ch.unicode() <= 0x097f) ||
+                    (ch.unicode() >= 0x3000 && ch.unicode() <= 0x303f)) {
+                    ++hep_count;
+                } else if (ch.isSurrogate() && ch.isHighSurrogate()) {
+                    ++i;
 
-                if (i < unicode_data.size()) {
-                    const QChar &next_ch = unicode_data.at(i);
+                    if (i < unicode_data.size()) {
+                        const QChar &next_ch = unicode_data.at(i);
 
-                    if (!next_ch.isLowSurrogate()) {
-                        --i;
-                        break;
-                    }
+                        if (!next_ch.isLowSurrogate()) {
+                            --i;
+                            break;
+                        }
 
-                    uint unicode = QChar::surrogateToUcs4(ch, next_ch);
+                        uint unicode = QChar::surrogateToUcs4(ch, next_ch);
 
-                    // emoji
-                    if (unicode >= 0x1f000 && unicode <= 0x1f6ff) {
-                        hep_count += 2;
+                        // emoji
+                        if (unicode >= 0x1f000 && unicode <= 0x1f6ff) {
+                            hep_count += 2;
+                        }
                     }
+                } else if (ch.unicode() == QChar::ReplacementCharacter) {
+                    ++replacement_count;
+                } else if (ch.unicode() > 0x7f) {
+                    // 因为UTF-8编码的容错性很低，所以未识别的编码只需要判断是否为 QChar::ReplacementCharacter 就能排除
+                    if (codec->name() != "UTF-8")
+                        ++unidentification_count;
                 }
-            } else if (ch.unicode() == QChar::ReplacementCharacter) {
-                ++replacement_count;
-            } else if (ch.unicode() > 0x7f) {
-                // 因为UTF-8编码的容错性很低，所以未识别的编码只需要判断是否为 QChar::ReplacementCharacter 就能排除
-                if (codec->name() != "UTF-8")
-                    ++unidentification_count;
-            }
-            break;
+                break;
         }
     }
 
@@ -190,20 +188,22 @@ QByteArray Utils::detectEncode(const QByteArray &data, const QString &fileName)
     }
 
     QMimeDatabase mime_database;
-    const QMimeType &mime_type = fileName.isEmpty() ? mime_database.mimeTypeForData(data) : mime_database.mimeTypeForFileNameAndData(fileName, data);
+    const QMimeType &mime_type =
+        fileName.isEmpty() ? mime_database.mimeTypeForData(data) : mime_database.mimeTypeForFileNameAndData(fileName, data);
     const QString &mimetype_name = mime_type.name();
     KEncodingProber::ProberType proberType = KEncodingProber::Universal;
 
-    if (mimetype_name == QStringLiteral("application/xml")
-        || mimetype_name == QStringLiteral("text/html")
-        || mimetype_name == QStringLiteral("application/xhtml+xml")) {
+    if (mimetype_name == QStringLiteral("application/xml") || mimetype_name == QStringLiteral("text/html") ||
+        mimetype_name == QStringLiteral("application/xhtml+xml")) {
         const QString &_data = QString::fromLatin1(data);
         QRegularExpression pattern("<\\bmeta.+\\bcharset=(?'charset'\\S+?)\\s*['\"/>]");
 
         pattern.setPatternOptions(QRegularExpression::DontCaptureOption | QRegularExpression::CaseInsensitiveOption);
-        const QString &charset = pattern.match(_data, 0, QRegularExpression::PartialPreferFirstMatch,
-                                               QRegularExpression::DontCheckSubjectStringMatchOption)
-                                         .captured("charset");
+        const QString &charset =
+            pattern
+                .match(
+                    _data, 0, QRegularExpression::PartialPreferFirstMatch, QRegularExpression::DontCheckSubjectStringMatchOption)
+                .captured("charset");
 
         if (!charset.isEmpty()) {
             return charset.toLatin1();
@@ -211,43 +211,45 @@ QByteArray Utils::detectEncode(const QByteArray &data, const QString &fileName)
 
         pattern.setPattern("<\\bmeta\\s+http-equiv=\"Content-Language\"\\s+content=\"(?'language'[a-zA-Z-]+)\"");
 
-        const QString &language = pattern.match(_data, 0, QRegularExpression::PartialPreferFirstMatch,
-                                                QRegularExpression::DontCheckSubjectStringMatchOption)
-                                          .captured("language");
+        const QString &language =
+            pattern
+                .match(
+                    _data, 0, QRegularExpression::PartialPreferFirstMatch, QRegularExpression::DontCheckSubjectStringMatchOption)
+                .captured("language");
 
         if (0 != language.size()) {
             QLocale l(language);
 
             switch (l.script()) {
-            case QLocale::ArabicScript:
-                proberType = KEncodingProber::Arabic;
-                break;
-            case QLocale::SimplifiedChineseScript:
-                proberType = KEncodingProber::ChineseSimplified;
-                break;
-            case QLocale::TraditionalChineseScript:
-                proberType = KEncodingProber::ChineseTraditional;
-                break;
-            case QLocale::CyrillicScript:
-                proberType = KEncodingProber::Cyrillic;
-                break;
-            case QLocale::GreekScript:
-                proberType = KEncodingProber::Greek;
-                break;
-            case QLocale::HebrewScript:
-                proberType = KEncodingProber::Hebrew;
-                break;
-            case QLocale::JapaneseScript:
-                proberType = KEncodingProber::Japanese;
-                break;
-            case QLocale::KoreanScript:
-                proberType = KEncodingProber::Korean;
-                break;
-            case QLocale::ThaiScript:
-                proberType = KEncodingProber::Thai;
-                break;
-            default:
-                break;
+                case QLocale::ArabicScript:
+                    proberType = KEncodingProber::Arabic;
+                    break;
+                case QLocale::SimplifiedChineseScript:
+                    proberType = KEncodingProber::ChineseSimplified;
+                    break;
+                case QLocale::TraditionalChineseScript:
+                    proberType = KEncodingProber::ChineseTraditional;
+                    break;
+                case QLocale::CyrillicScript:
+                    proberType = KEncodingProber::Cyrillic;
+                    break;
+                case QLocale::GreekScript:
+                    proberType = KEncodingProber::Greek;
+                    break;
+                case QLocale::HebrewScript:
+                    proberType = KEncodingProber::Hebrew;
+                    break;
+                case QLocale::JapaneseScript:
+                    proberType = KEncodingProber::Japanese;
+                    break;
+                case QLocale::KoreanScript:
+                    proberType = KEncodingProber::Korean;
+                    break;
+                case QLocale::ThaiScript:
+                    proberType = KEncodingProber::Thai;
+                    break;
+                default:
+                    break;
             }
         }
     } else if (mimetype_name == "text/x-python") {
@@ -255,7 +257,11 @@ QByteArray Utils::detectEncode(const QByteArray &data, const QString &fileName)
         QTextStream stream(data);
 
         pattern.setPatternOptions(QRegularExpression::DontCaptureOption | QRegularExpression::CaseInsensitiveOption);
+#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
         stream.setCodec("latin1");
+#else
+        stream.setEncoding(QStringConverter::Latin1);
+#endif
 
         while (!stream.atEnd()) {
             const QString &_data = stream.readLine();
@@ -268,11 +274,11 @@ QByteArray Utils::detectEncode(const QByteArray &data, const QString &fileName)
     }
 
     // for CJK
-    const QList<QPair<KEncodingProber::ProberType, QLocale::Country>> fallback_list {
-        { KEncodingProber::ChineseSimplified, QLocale::China },
-        { KEncodingProber::ChineseTraditional, QLocale::China },
-        { KEncodingProber::Japanese, QLocale::Japan },
-        { KEncodingProber::Korean, QLocale::NorthKorea },
+    const QList<QPair<KEncodingProber::ProberType, QLocale::Country>> fallback_list{
+        {KEncodingProber::ChineseSimplified, QLocale::China},
+        {KEncodingProber::ChineseTraditional, QLocale::China},
+        {KEncodingProber::Japanese, QLocale::Japan},
+        {KEncodingProber::Korean, QLocale::NorthKorea},
         //{KEncodingProber::Cyrillic, QLocale::Russia},
         //{KEncodingProber::Greek, QLocale::Greece},
         //{proberType, QLocale::system().country()}
@@ -576,7 +582,9 @@ bool Utils::isMimeTypeSupport(const QString &filepath)
                   << "application/x-pak"
                   << "application/x-code-workspace"
                   << "application/toml"
-                  << "audio/x-mod";
+                  << "audio/x-mod"
+                  << "application/pkix-attr-cert"
+                  << "application/x-x509-ca-cert";
 
     if (textMimeTypes.contains(mimeType)) {
         return true;
@@ -587,8 +595,8 @@ bool Utils::isMimeTypeSupport(const QString &filepath)
 
 bool Utils::isDraftFile(const QString &filepath)
 {
-    QString draftDir = QDir(Utils::cleanPath(QStandardPaths::standardLocations(QStandardPaths::DataLocation)).first())
-                               .filePath("blank-files");
+    QString draftDir = QDir(Utils::cleanPath(QStandardPaths::standardLocations(QStandardPaths::AppDataLocation)).first())
+                           .filePath("blank-files");
     draftDir = QDir::cleanPath(draftDir);
     QString dir = QFileInfo(filepath).dir().absolutePath();
     return dir == draftDir;
@@ -600,8 +608,8 @@ bool Utils::isDraftFile(const QString &filepath)
  */
 bool Utils::isBackupFile(const QString &filepath)
 {
-    QString backupDir = QDir(Utils::cleanPath(QStandardPaths::standardLocations(QStandardPaths::DataLocation)).first())
-                                .filePath("backup-files");
+    QString backupDir = QDir(Utils::cleanPath(QStandardPaths::standardLocations(QStandardPaths::AppDataLocation)).first())
+                            .filePath("backup-files");
     QString dir = QFileInfo(filepath).dir().absolutePath();
     return dir == backupDir;
 }
@@ -623,9 +631,8 @@ QStringList Utils::cleanPath(const QStringList &filePaths)
  */
 QString Utils::localDataPath()
 {
-    auto dataPaths = Utils::cleanPath(QStandardPaths::standardLocations(QStandardPaths::DataLocation));
-    return dataPaths.isEmpty() ? QDir::homePath() + "/.local/share/deepin/deepin-editor/"
-                               : dataPaths.first();
+    auto dataPaths = Utils::cleanPath(QStandardPaths::standardLocations(QStandardPaths::AppDataLocation));
+    return dataPaths.isEmpty() ? QDir::homePath() + "/.local/share/deepin/deepin-editor/" : dataPaths.first();
 }
 
 const QStringList Utils::getEncodeList()
@@ -690,16 +697,16 @@ void Utils::clearChildrenFocus(QObject *objParent)
 {
     // 可以获取焦点的控件名称列表
     QStringList foucswidgetlist;
-    //foucswidgetlist << "QLineEdit" << TERM_WIDGET_NAME;
+    // foucswidgetlist << "QLineEdit" << TERM_WIDGET_NAME;
 
-    //qDebug() << "checkChildrenFocus start" << objParent->children().size();
+    // qDebug() << "checkChildrenFocus start" << objParent->children().size();
     for (QObject *obj : objParent->children()) {
         if (!obj->isWidgetType()) {
             continue;
         }
         QWidget *widget = static_cast<QWidget *>(obj);
         if (Qt::NoFocus != widget->focusPolicy()) {
-            //qDebug() << widget << widget->focusPolicy() << widget->metaObject()->className();
+            // qDebug() << widget << widget->focusPolicy() << widget->metaObject()->className();
             if (!foucswidgetlist.contains(widget->metaObject()->className())) {
                 widget->setFocusPolicy(Qt::NoFocus);
             }
@@ -707,7 +714,7 @@ void Utils::clearChildrenFocus(QObject *objParent)
         clearChildrenFocus(obj);
     }
 
-    //qDebug() << "checkChildrenFocus over" << objParent->children().size();
+    // qDebug() << "checkChildrenFocus over" << objParent->children().size();
 }
 
 void Utils::clearChildrenFoucusEx(QWidget *pWidget)
@@ -716,7 +723,8 @@ void Utils::clearChildrenFoucusEx(QWidget *pWidget)
 
     QObjectList childern = pWidget->children();
 
-    if (childern.size() <= 0) return;
+    if (childern.size() <= 0)
+        return;
 
     foreach (QObject *child, childern) {
         if (!child->isWidgetType()) {
@@ -734,7 +742,8 @@ void Utils::setChildrenFocus(QWidget *pWidget, Qt::FocusPolicy policy)
 
     QObjectList childern = pWidget->children();
 
-    if (childern.size() <= 0) return;
+    if (childern.size() <= 0)
+        return;
 
     foreach (QObject *child, childern) {
         if (!child->isWidgetType()) {
@@ -785,8 +794,8 @@ void Utils::killProcessByName(const char *pstrName)
 
 QString Utils::getStringMD5Hash(const QString &input)
 {
-    QByteArray byteArray;
-    byteArray.append(input);
+    QByteArray byteArray = input.toUtf8();
+    ;
     QByteArray md5Path = QCryptographicHash::hash(byteArray, QCryptographicHash::Md5);
 
     return md5Path.toHex();
@@ -796,9 +805,8 @@ bool Utils::activeWindowFromDock(quintptr winId)
 {
     bool bRet = false;
     // 优先采用V23接口
-    QDBusInterface dockDbusInterfaceV23("org.deepin.dde.daemon.Dock1",
-                                        "/org/deepin/dde/daemon/Dock1",
-                                        "org.deepin.dde.daemon.Dock1");
+    QDBusInterface dockDbusInterfaceV23(
+        "org.deepin.dde.daemon.Dock1", "/org/deepin/dde/daemon/Dock1", "org.deepin.dde.daemon.Dock1");
     if (dockDbusInterfaceV23.isValid()) {
         QDBusReply<void> reply = dockDbusInterfaceV23.call("ActivateWindow", winId);
         if (!reply.isValid()) {
@@ -808,9 +816,8 @@ bool Utils::activeWindowFromDock(quintptr winId)
         }
     }
 
-    QDBusInterface dockDbusInterfaceV20("com.deepin.dde.daemon.Dock",
-                                        "/com/deepin/dde/daemon/Dock",
-                                        "com.deepin.dde.daemon.Dock");
+    QDBusInterface dockDbusInterfaceV20(
+        "com.deepin.dde.daemon.Dock", "/com/deepin/dde/daemon/Dock", "com.deepin.dde.daemon.Dock");
     if (dockDbusInterfaceV20.isValid() && !bRet) {
         QDBusReply<void> reply = dockDbusInterfaceV20.call("ActivateWindow", winId);
         if (!reply.isValid()) {
@@ -853,17 +860,17 @@ QString Utils::getSystemLan()
         return m_systemLanguage;
     } else {
         switch (getSystemVersion()) {
-        case V23:
-            m_systemLanguage = QLocale::system().name();
-            break;
-        default: {
-            QDBusInterface ie("com.deepin.daemon.LangSelector",
-                              "/com/deepin/daemon/LangSelector",
-                              "com.deepin.daemon.LangSelector",
-                              QDBusConnection::sessionBus());
-            m_systemLanguage = ie.property("CurrentLocale").toString();
-            break;
-        }
+            case V23:
+                m_systemLanguage = QLocale::system().name();
+                break;
+            default: {
+                QDBusInterface ie("com.deepin.daemon.LangSelector",
+                                  "/com/deepin/daemon/LangSelector",
+                                  "com.deepin.daemon.LangSelector",
+                                  QDBusConnection::sessionBus());
+                m_systemLanguage = ie.property("CurrentLocale").toString();
+                break;
+            }
         }
 
         qWarning() << "getSystemLan is" << m_systemLanguage;
@@ -888,7 +895,7 @@ Utils::SystemVersion Utils::getSystemVersion()
     return V20;
 }
 
-//judge whether the protocol is wayland
+// judge whether the protocol is wayland
 bool Utils::isWayland()
 {
     static QString protocol;
@@ -899,7 +906,6 @@ bool Utils::isWayland()
     return protocol.contains("wayland");
 }
 
-
 QString Utils::lineFeed(const QString &text, int nWidth, const QFont &font, int nElidedRow)
 {
     if (nElidedRow < 0)
@@ -914,7 +920,7 @@ QString Utils::lineFeed(const QString &text, int nWidth, const QFont &font, int
 
     if (!strText.isEmpty()) {
         for (int i = 1; i <= strText.size(); i++) {
-            if (fm.width(strText.left(i)) >= nWidth) {
+            if (fm.horizontalAdvance(strText.left(i)) >= nWidth) {
                 if (strListLine.size() + 1 == nElidedRow)
                     break;
 
@@ -1020,7 +1026,8 @@ QString Utils::libPath(const QString &strlib)
     QDir dir;
     QString path = QLibraryInfo::location(QLibraryInfo::LibrariesPath);
     dir.setPath(path);
-    QStringList list = dir.entryList(QStringList() << (strlib + "*"), QDir::NoDotAndDotDot | QDir::Files);   //filter name with strlib
+    QStringList list =
+        dir.entryList(QStringList() << (strlib + "*"), QDir::NoDotAndDotDot | QDir::Files);  // filter name with strlib
 
     if (list.contains(strlib))
         return strlib;
@@ -1088,15 +1095,16 @@ void Utils::recordCloseFile(const QString &filePath)
 void Utils::sendFloatMessageFixedFont(QWidget *par, const QIcon &icon, const QString &message)
 {
     // 以下代码和 DMessageManager::sendMessage() 流程一致。
-    QWidget *content = par->findChild<QWidget *>("_d_message_manager_content", Qt::FindDirectChildrenOnly);
-    auto msgWidgets = content->findChildren<DFloatingMessage *>(QString(), Qt::FindDirectChildrenOnly);
-    auto text_message_count = std::count_if(msgWidgets.begin(), msgWidgets.end(), [](DFloatingMessage *msg) {
-        return bool(msg->messageType() == DFloatingMessage::TransientType);
-    });
+    if (QWidget *content = par->findChild<QWidget *>("_d_message_manager_content", Qt::FindDirectChildrenOnly)) {
+        auto msgWidgets = content->findChildren<DFloatingMessage *>(QString(), Qt::FindDirectChildrenOnly);
+        auto text_message_count = std::count_if(msgWidgets.begin(), msgWidgets.end(), [](DFloatingMessage *msg) {
+            return bool(msg->messageType() == DFloatingMessage::TransientType);
+        });
 
-    // TransientType 类型的通知消息，最多只允许同时显示三个
-    if (text_message_count >= 3)
-        return;
+        // TransientType 类型的通知消息，最多只允许同时显示三个
+        if (text_message_count >= 3)
+            return;
+    }
 
     // 浮动临时提示信息，自动销毁
     DFloatingMessage *floMsg = new DFloatingMessage(DFloatingMessage::TransientType);
@@ -1114,3 +1122,125 @@ void Utils::sendFloatMessageFixedFont(QWidget *par, const QIcon &icon, const QSt
 
     DMessageManager::instance()->sendMessage(par, floMsg);
 }
+
+/**
+ * @brief Gets system memory information from /proc/meminfo
+ * @param[out] totalMemory Total system memory in KB
+ * @param[out] freeMemory Available memory in KB (MemAvailable if exists, otherwise MemFree+Buffers+Cached)
+ * @return True if memory info was successfully read and parsed, false otherwise
+ */
+bool Utils::getSystemMemoryInfo(qlonglong &totalMemory, qlonglong &freeMemory)
+{
+    qlonglong memFree = 0;
+    qlonglong buffers = 0;
+    qlonglong cached = 0;
+    bool valueOk = false;
+
+    QFile file(PROC_MEMINFO_PATH);
+    if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) {
+        qWarning() << "Utils: Failed to open" << PROC_MEMINFO_PATH << "for memory check.";
+        return false;
+    }
+
+    QByteArray allData = file.readAll();
+    file.close();
+
+    QTextStream stream(allData);
+    QString line;
+    while (!stream.atEnd()) {
+        line = stream.readLine();
+        if (line.startsWith("MemTotal:")) {
+            totalMemory = line.section(':', 1, 1).trimmed().section(' ', 0, 0).toLongLong(&valueOk);
+        } else if (line.startsWith("MemFree:")) {
+            memFree = line.section(':', 1, 1).trimmed().section(' ', 0, 0).toLongLong(&valueOk);
+        } else if (line.startsWith("Buffers:")) {
+            buffers = line.section(':', 1, 1).trimmed().section(' ', 0, 0).toLongLong(&valueOk);
+        } else if (line.startsWith("Cached:")) {
+            cached = line.section(':', 1, 1).trimmed().section(' ', 0, 0).toLongLong(&valueOk);
+        } else if (line.startsWith("MemAvailable:")) {
+            freeMemory = line.section(':', 1, 1).trimmed().section(' ', 0, 0).toLongLong(&valueOk);
+            break;
+        }
+        if (stream.atEnd() && freeMemory == 0) {
+            freeMemory = memFree + buffers + cached;
+        }
+    }
+
+    return (totalMemory > 0 && freeMemory > 0);
+}
+
+/**
+ * @brief Checks if the system has sufficient memory to perform the specified operation.
+ * @param operationType The type of operation (Copy/Paste).
+ * @param operationDataSize The size of the data involved in the operation (bytes).
+ * @param currentDocumentSize The current size of the document (characters/bytes).
+ * @return True if memory is sufficient, false otherwise.
+ */
+bool Utils::isMemorySufficientForOperation(OperationType operationType, qlonglong operationDataSize, qlonglong currentDocumentSize)
+{
+    qlonglong memoryFree = 0;
+    qlonglong memoryTotal = 0;
+
+    if (!getSystemMemoryInfo(memoryTotal, memoryFree)) {
+        // Conservatively allow the operation if memory info cannot be read
+        return true;
+    }
+
+    // Convert KB to Bytes for comparison
+    qlonglong availableMemoryBytes = memoryFree * DATA_SIZE_1024;
+    qlonglong totalMemoryBytes = memoryTotal * DATA_SIZE_1024;
+
+    // Judge based on operation type
+    switch (operationType) {
+        case OperationType::RawOperation:
+            // Raw operation: Directly compare the data size with available memory
+            if (operationDataSize > availableMemoryBytes) {
+                qWarning() << "Utils: Insufficient memory for raw operation. Needed:" << operationDataSize << "Available:" << availableMemoryBytes;
+                return false;
+            }
+            break;
+            
+        case OperationType::CopyOperation: {
+            // Copy operation: Estimated memory consumption = data size * factor
+            qlonglong estimatedMemoryNeeded = operationDataSize * COPY_CONSUME_MEMORY_MULTIPLE;
+            if (estimatedMemoryNeeded > availableMemoryBytes) {
+                qWarning() << "Utils: Insufficient memory for copy operation. Needed(est):" << estimatedMemoryNeeded << "Available:" << availableMemoryBytes;
+                return false;
+            }
+            break;
+        }
+            
+        case OperationType::PasteOperation: {
+            // Paste operation: Estimated memory consumption = paste data size * factor
+            qlonglong estimatedMemoryNeededForPaste = operationDataSize * PASTE_CONSUME_MEMORY_MULTIPLE;
+            // Estimated total document memory after paste
+            qlonglong estimatedTotalDocMemory = (currentDocumentSize + operationDataSize) * PASTE_CONSUME_MEMORY_MULTIPLE;
+
+            // Check if pasting the data itself would cause insufficient memory
+            if (estimatedMemoryNeededForPaste > availableMemoryBytes) {
+                qWarning() << "Utils: Insufficient memory for paste operation (paste data). Needed(est):" << estimatedMemoryNeededForPaste << "Available:" << availableMemoryBytes;
+                return false;
+            }
+
+            // Check if the estimated total document size after paste exceeds total system memory
+            if (estimatedTotalDocMemory > totalMemoryBytes) {
+                qWarning() << "Utils: Paste operation might exceed total system memory. Estimated total doc memory:" << estimatedTotalDocMemory << "Total system memory:" << totalMemoryBytes;
+                return false;
+            }
+
+            // Check specific threshold: Restrict paste size if document reaches 800MB
+            const qlonglong DOC_SIZE_LIMIT_800MB = 800LL * DATA_SIZE_1024 * DATA_SIZE_1024;
+            const qlonglong PASTE_SIZE_LIMIT_500KB = 500LL * DATA_SIZE_1024;
+            if (currentDocumentSize > DOC_SIZE_LIMIT_800MB && operationDataSize > PASTE_SIZE_LIMIT_500KB) {
+                qWarning() << "Utils: Paste operation restricted. Document size exceeds 800MB and paste data exceeds 500KB.";
+                return false;
+            }
+            break;
+        }
+
+        default:
+            break;
+    }
+
+    return true; // Memory is sufficient
+}
