@@ -15,14 +15,12 @@
 #include <DMainWindow>
 #include <DWidgetUtil>
 #include <DLog>
-#include <DApplicationSettings>
 #include <DSettingsOption>
 
 #include <QApplication>
 #include <QCommandLineParser>
 #include <QDBusConnection>
 #include <QDBusInterface>
-#include <QDesktopWidget>
 #include <QScreen>
 #include <QDebug>
 
@@ -39,11 +37,10 @@ int main(int argc, char *argv[])
     }
 
     QCoreApplication::setAttribute(Qt::AA_UseOpenGLES);
-    // QGuiApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
 
     EditorApplication app(argc, argv);
     // save theme
-    DApplicationSettings savetheme;
+    // DApplicationSettings savetheme;
 
     // 需在App构造后初始化日志设置
     DLogManager::registerConsoleAppender();
