@@ -6,14 +6,15 @@
 //#include <settings.h>
 
 #include <DApplication>
-#include <QDesktopWidget>
 #include <DWidgetUtil>
 #include <QDebug>
 #include <QScreen>
 #include <QPropertyAnimation>
 #include <DSettingsOption>
 #include <DAboutDialog>
-//#include <DSettings>
+#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
+#include <QDesktopWidget>
+#endif
 
 #include "common/iflytek_ai_assistant.h"
 
@@ -47,9 +48,9 @@ StartManager::StartManager(QObject *parent)
 
     initBlockShutdown();
 
-    m_blankFileDir = QDir(Utils::cleanPath(QStandardPaths::standardLocations(QStandardPaths::DataLocation)).first()).filePath("blank-files");
-    m_backupDir = QDir(Utils::cleanPath(QStandardPaths::standardLocations(QStandardPaths::DataLocation)).first()).filePath("backup-files");
-    m_autoBackupDir = QDir(Utils::cleanPath(QStandardPaths::standardLocations(QStandardPaths::DataLocation)).first()).filePath("autoBackup-files");
+    m_blankFileDir = QDir(Utils::cleanPath(QStandardPaths::standardLocations(QStandardPaths::AppDataLocation)).first()).filePath("blank-files");
+    m_backupDir = QDir(Utils::cleanPath(QStandardPaths::standardLocations(QStandardPaths::AppDataLocation)).first()).filePath("backup-files");
+    m_autoBackupDir = QDir(Utils::cleanPath(QStandardPaths::standardLocations(QStandardPaths::AppDataLocation)).first()).filePath("autoBackup-files");
 
     if (!QFileInfo(m_blankFileDir).exists()) {
         QDir().mkpath(m_blankFileDir);
@@ -418,7 +419,8 @@ void StartManager::openFilesInWindow(QStringList files)
         window->activateWindow();
     } else {
         for (const QString &file : files) {
-            FileTabInfo info = getFileTabInfo(file);
+            QString canonicalFile = QFileInfo(file).canonicalFilePath();
+            FileTabInfo info = getFileTabInfo(canonicalFile);
 
             // Open exist tab if file has opened.
             if (info.windowIndex != -1) {
@@ -428,7 +430,7 @@ void StartManager::openFilesInWindow(QStringList files)
             else {
                 Window *window = createWindow();
                 window->showCenterWindow(true);
-                window->addTab(file);
+                window->addTab(canonicalFile);
             }
         }
     }
@@ -437,7 +439,7 @@ void StartManager::openFilesInWindow(QStringList files)
 void StartManager::openFilesInTab(QStringList files)
 {
     if (files.isEmpty()) {
-        QDir blankDirectory = QDir(QDir(Utils::cleanPath(QStandardPaths::standardLocations(QStandardPaths::DataLocation)).first()).filePath("blank-files"));
+        QDir blankDirectory = QDir(QDir(Utils::cleanPath(QStandardPaths::standardLocations(QStandardPaths::AppDataLocation)).first()).filePath("blank-files"));
         QStringList blankFiles = blankDirectory.entryList(QStringList(), QDir::Files);
 
         if (m_windows.isEmpty()) {
@@ -470,13 +472,13 @@ void StartManager::openFilesInTab(QStringList files)
         }
     } else {
         for (const QString &file : files) {
-
-            if (!checkPath(file)) {
+            QString canonicalFile = QFileInfo(file).canonicalFilePath();
+            if (!checkPath(canonicalFile)) {
                 // 存在已打开文件时，进行下一文件判断
                 continue;
             }
 
-            FileTabInfo info = getFileTabInfo(file);
+            FileTabInfo info = getFileTabInfo(canonicalFile);
 
             // Open exist tab if file has opened.
             if (info.windowIndex != -1) {
@@ -488,13 +490,13 @@ void StartManager::openFilesInTab(QStringList files)
                 window->showCenterWindow(true);
                 QTimer::singleShot(50, [ = ] {
                     recoverFile(window);
-                    window->addTab(file);
+                    window->addTab(canonicalFile);
                 });
             }
             // Open file tab in first window of window list.
             else {
                 Window *window = m_windows[0];
-                window->addTab(file);
+                window->addTab(canonicalFile);
                 //window->setWindowState(Qt::WindowActive);
                 //通过dbus接口从任务栏激活窗口
                 if (!Q_LIKELY(Utils::activeWindowFromDock(window->winId()))) {
@@ -511,7 +513,11 @@ void StartManager::createWindowFromWrapper(const QString &tabName, const QString
     //window->showCenterWindow();
     QRect rect = pWindow->rect();
     QPoint pos = QCursor::pos() ;/*- window->topLevelWidget()->pos();*/
+#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
     QRect desktopRect = QApplication::desktop()->rect();
+#else
+    QRect desktopRect = QGuiApplication::primaryScreen()->availableGeometry();
+#endif
     QPoint startPos = pos;
 
     if ((pos.x() + rect.width()) > desktopRect.width()) {
@@ -712,7 +718,11 @@ void StartManager::initWindowPosition(Window *window, bool alwaysCenter)
     } else {
         // Add window offset to avoid all editor window popup at same coordinate.
         int windowOffset = m_windows.size() * 50;
+#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
         QRect screenGeometry = qApp->desktop()->screenGeometry(QCursor::pos());
+#else
+        QRect screenGeometry = QGuiApplication::primaryScreen()->availableGeometry();
+#endif
         window->move(screenGeometry.x() + windowOffset, screenGeometry.y() + windowOffset);
     }
 }
